@@ -3,14 +3,14 @@ package vals
 import (
 	"context"
 	"fmt"
-	config2 "github.com/variantdev/vals/pkg/config"
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/hashicorp/vault/api"
+
+	config2 "github.com/helmfile/vals/pkg/config"
 )
 
 type Conn struct {
@@ -91,10 +91,10 @@ func TestValues_Vault_EvalTemplate(t *testing.T) {
 	addr, stop := SetupVaultKV(
 		t,
 		map[string]map[string]interface{}{
-			"mykv/foo": map[string]interface{}{
+			"mykv/foo": {
 				"mykey": "myvalue",
 			},
-			"mykv/objs": map[string]interface{}{
+			"mykv/objs": {
 				"myyaml": `yamlkey1: yamlval1
 `,
 				"myjson": `{"jsonkey1":"jsonval1"}
@@ -537,12 +537,12 @@ func TestValues_Vault_Map_YAML(t *testing.T) {
 	//
 	// vault write mykv/yamltest myyaml="$(cat myyaml.yaml)" myjson="$(cat myjson.json)"
 
-	yamlContent, err := ioutil.ReadFile("myyaml.yaml")
+	yamlContent, err := os.ReadFile("myyaml.yaml")
 	if err != nil {
 		t.Fatalf("%v", err)
 	}
 
-	jsonContent, err := ioutil.ReadFile("myjson.json")
+	jsonContent, err := os.ReadFile("myjson.json")
 	if err != nil {
 		t.Fatalf("%v", err)
 	}
@@ -550,7 +550,7 @@ func TestValues_Vault_Map_YAML(t *testing.T) {
 	addr, stop := SetupVaultKV(
 		t,
 		map[string]map[string]interface{}{
-			"mykv/yamltest": map[string]interface{}{
+			"mykv/yamltest": {
 				"myyaml": string(yamlContent),
 				"myjson": string(jsonContent),
 			},
